diff src/lstream.h @ 867:804517e16990

[xemacs-hg @ 2002-06-05 09:54:39 by ben] Textual renaming: text/char names abbrev.c, alloc.c, buffer.c, buffer.h, bytecode.c, callint.c, casefiddle.c, casetab.c, charset.h, chartab.c, chartab.h, cmds.c, console-gtk.h, console-msw.c, console-msw.h, console-stream.c, console-tty.c, console-x.c, console-x.h, console.h, data.c, device-msw.c, device-x.c, dialog-msw.c, dired-msw.c, dired.c, doc.c, doprnt.c, editfns.c, eldap.c, emodules.c, eval.c, event-Xt.c, event-gtk.c, event-msw.c, event-stream.c, event-unixoid.c, events.c, events.h, file-coding.c, file-coding.h, fileio.c, filelock.c, fns.c, font-lock.c, frame-gtk.c, frame-msw.c, frame-x.c, frame.c, glyphs-eimage.c, glyphs-msw.c, glyphs-x.c, glyphs.c, glyphs.h, gpmevent.c, gui-x.c, gui-x.h, gui.c, gui.h, hpplay.c, indent.c, insdel.c, insdel.h, intl-win32.c, keymap.c, line-number.c, line-number.h, lisp-disunion.h, lisp-union.h, lisp.h, lread.c, lrecord.h, lstream.c, lstream.h, md5.c, menubar-msw.c, menubar-x.c, menubar.c, minibuf.c, mule-ccl.c, mule-charset.c, mule-coding.c, mule-wnnfns.c, ndir.h, nt.c, objects-gtk.c, objects-gtk.h, objects-msw.c, objects-tty.c, objects-x.c, objects.c, objects.h, postgresql.c, print.c, process-nt.c, process-unix.c, process.c, procimpl.h, realpath.c, redisplay-gtk.c, redisplay-msw.c, redisplay-output.c, redisplay-tty.c, redisplay-x.c, redisplay.c, redisplay.h, regex.c, search.c, select-common.h, select-gtk.c, select-x.c, sound.h, symbols.c, syntax.c, syntax.h, sysdep.c, sysdep.h, sysdir.h, sysfile.h, sysproc.h, syspwd.h, systime.h, syswindows.h, termcap.c, tests.c, text.c, text.h, toolbar-common.c, tooltalk.c, ui-gtk.c, unexnt.c, unicode.c, win32.c: Text/char naming rationalization. [a] distinguish between "charptr" when it refers to operations on the pointer itself and when it refers to operations on text; and [b] use consistent naming for everything referring to internal format, i.e. Itext == text in internal format Ibyte == a byte in such text Ichar == a char as represented in internal character format thus e.g. set_charptr_emchar -> set_itext_ichar The pre and post tags on either side of this change are: pre-internal-format-textual-renaming post-internal-format-textual-renaming See the Internals Manual for details of exactly how this was done, how to handle the change in your workspace, etc.
author ben
date Wed, 05 Jun 2002 09:58:45 +0000
parents 6728e641994e
children e22b0213b713
line wrap: on
line diff
--- a/src/lstream.h	Tue Jun 04 17:40:00 2002 +0000
+++ b/src/lstream.h	Wed Jun 05 09:58:45 2002 +0000
@@ -355,50 +355,50 @@
 
 
 /************************************************************************/
-/*             working with an Lstream as a stream of Emchars           */
+/*             working with an Lstream as a stream of Ichars           */
 /************************************************************************/
 
 #ifdef MULE
 
 DECLARE_INLINE_HEADER (
-Emchar
-Lstream_get_emchar (Lstream *stream)
+Ichar
+Lstream_get_ichar (Lstream *stream)
 )
 {
   int c = Lstream_getc (stream);
   return (c < 0x80		/* c == EOF || byte_ascii_p (c) */
-	  ? (Emchar) c
-	  : Lstream_get_emchar_1 (stream, c));
+	  ? (Ichar) c
+	  : Lstream_get_ichar_1 (stream, c));
 }
 
 /* Write an Emchar to a stream.  Return value is 0 for success, -1 for
    failure. */
 
 DECLARE_INLINE_HEADER (
 int
-Lstream_put_emchar (Lstream *stream, Emchar ch)
+Lstream_put_ichar (Lstream *stream, Ichar ch)
 )
 {
-  return emchar_ascii_p (ch) ?
+  return ichar_ascii_p (ch) ?
     Lstream_putc (stream, ch) :
-    Lstream_fput_emchar (stream, ch);
+    Lstream_fput_ichar (stream, ch);
 }
 
 DECLARE_INLINE_HEADER (
 void
-Lstream_unget_emchar (Lstream *stream, Emchar ch)
+Lstream_unget_ichar (Lstream *stream, Ichar ch)
 )
 {
-  if (emchar_ascii_p (ch))
+  if (ichar_ascii_p (ch))
     Lstream_ungetc (stream, ch);
   else
-    Lstream_funget_emchar (stream, ch);
+    Lstream_funget_ichar (stream, ch);
 }
 #else /* not MULE */
 
-# define Lstream_get_emchar(stream) Lstream_getc (stream)
-# define Lstream_put_emchar(stream, ch) Lstream_putc (stream, ch)
-# define Lstream_unget_emchar(stream, ch) Lstream_ungetc (stream, ch)
+# define Lstream_get_ichar(stream) Lstream_getc (stream)
+# define Lstream_put_ichar(stream, ch) Lstream_putc (stream, ch)
+# define Lstream_unget_ichar(stream, ch) Lstream_ungetc (stream, ch)
 
 #endif /* not MULE */
 
@@ -433,7 +433,7 @@
 					 int flags);
 void filedesc_stream_set_pty_flushing (Lstream *stream,
 				       int pty_max_bytes,
-				       Intbyte eof_char);
+				       Ibyte eof_char);
 int filedesc_stream_fd (Lstream *stream);
 Lisp_Object make_lisp_string_input_stream (Lisp_Object string,
 					   Bytecount offset,
@@ -355,50 +355,50 @@
 }
 
-/* Write an Emchar to a stream.  Return value is 0 for success, -1 for
+/* Write an Ichar to a stream.  Return value is 0 for success, -1 for
    failure. */
 